@@ -20,7 +20,12 @@ bool PackageManager::search( const QString & /*file*/ ) { return false; }
 
 int PackageManager::capabilities( int /*query*/ ) const { return 0; }
 
-QString PackageManager::getOnlineForm() { return QString::null; };
-QString PackageManager::getOnlineURL(const QString& /* query */, const QMap<QString, QString>& /*options*/) { return QString::null; };
+QString PackageManager::getOnlineForm() 
+{ return QString::null; }
+QString PackageManager::getOnlineURL
+    ( const QString& /* query */
+    , const QMap<QString, QString>& /*options*/ )  
+{ return QString::null; }
 
 #include "packagemanager.moc"
+
